"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[6910],{66910:(e,t,s)=>{s.r(t),s.d(t,{StyleModule:()=>o});const l="undefined"==typeof Symbol?"__ͼ":Symbol.for("ͼ"),i="undefined"==typeof Symbol?"__styleSet"+Math.floor(1e8*Math.random()):Symbol("styleSet"),n="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:{};class o{constructor(e,t){this.rules=[];let{finish:s}=t||{};function l(e){return/^@/.test(e)?[e]:e.split(/,\s*/)}function i(e,t,n,o){let r=[],h=/^@(\w+)\b/.exec(e[0]),u=h&&"keyframes"==h[1];if(h&&null==t)return n.push(e[0]+";");for(let s in t){let o=t[s];if(/&/.test(s))i(s.split(/,\s*/).map((t=>e.map((e=>t.replace(/&/,e))))).reduce(((e,t)=>e.concat(t))),o,n);else if(o&&"object"==typeof o){if(!h)throw new RangeError("The value of a property ("+s+") should be a primitive value.");i(l(s),o,r,u)}else null!=o&&r.push(s.replace(/_.*/,"").replace(/[A-Z]/g,(e=>"-"+e.toLowerCase()))+": "+o+";")}(r.length||u)&&n.push((!s||h||o?e:e.map(s)).join(", ")+" {"+r.join(" ")+"}")}for(let t in e)i(l(t),e[t],this.rules)}getRules(){return this.rules.join("\n")}static newName(){let e=n[l]||1;return n[l]=e+1,"ͼ"+e.toString(36)}static mount(e,t,s){let l=e[i],n=s&&s.nonce;l?n&&l.setNonce(n):l=new h(e,n),l.mount(Array.isArray(t)?t:[t],e)}}let r=new Map;class h{constructor(e,t){let s=e.ownerDocument||e,l=s.defaultView;if(!e.head&&e.adoptedStyleSheets&&l.CSSStyleSheet){let t=r.get(s);if(t)return e[i]=t;this.sheet=new l.CSSStyleSheet,r.set(s,this)}else this.styleTag=s.createElement("style"),t&&this.styleTag.setAttribute("nonce",t);this.modules=[],e[i]=this}mount(e,t){let s=this.sheet,l=0,i=0;for(let t=0;t<e.length;t++){let n=e[t],o=this.modules.indexOf(n);if(o<i&&o>-1&&(this.modules.splice(o,1),i--,o=-1),-1==o){if(this.modules.splice(i++,0,n),s)for(let e=0;e<n.rules.length;e++)s.insertRule(n.rules[e],l++)}else{for(;i<o;)l+=this.modules[i++].rules.length;l+=n.rules.length,i++}}if(s)t.adoptedStyleSheets.indexOf(this.sheet)<0&&(t.adoptedStyleSheets=[this.sheet,...t.adoptedStyleSheets]);else{let e="";for(let t=0;t<this.modules.length;t++)e+=this.modules[t].getRules()+"\n";this.styleTag.textContent=e;let s=t.head||t;this.styleTag.parentNode!=s&&s.insertBefore(this.styleTag,s.firstChild)}}setNonce(e){this.styleTag&&this.styleTag.getAttribute("nonce")!=e&&this.styleTag.setAttribute("nonce",e)}}}}]);
//# sourceMappingURL=6910.js.map